@@ -1,16 +1,17 @@
 /*
-  Copyright (c) 2016, 2023, Oracle and/or its affiliates.
+  Copyright (c) 2016, 2024, Oracle and/or its affiliates.
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.
 
-  This program is also distributed with certain software (including
+  This program is designed to work with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
-  separately licensed software that they have included with MySQL.
+  separately licensed software that they have either included with
+  the program or referenced in the documentation.
 
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -110,6 +111,8 @@ class ConfigGenerator {
     keyring_info_ = keyring_info;
   }
 
+  void set_plugin_folder(const std::string &val) { plugin_folder_ = val; }
+
   struct Options {
     struct Endpoint {
       int port;
@@ -260,8 +263,8 @@ class ConfigGenerator {
 
   // returns bootstrap report (several lines of human-readable text) if desired
   std::string bootstrap_deployment(
-      const std::string &program_name, std::ostream &config_file,
-      std::ostream &state_file, const mysql_harness::Path &config_file_path,
+      const std::string &program_name, std::ofstream &config_file,
+      std::ofstream &state_file, const mysql_harness::Path &config_file_path,
       const mysql_harness::Path &state_file_path, const std::string &name,
       const std::map<std::string, std::string> &options,
       const std::map<std::string, std::vector<std::string>> &multivalue_options,
@@ -282,7 +285,7 @@ class ConfigGenerator {
       const Options &options,
       const std::map<std::string, std::string> &default_paths,
       const std::map<std::string, std::string> &config_overwrites,
-      const std::string &state_file_name = "");
+      const std::string &state_file_name, const bool full);
 
   void print_bootstrap_start_msg(uint32_t router_id, bool directory_deployment,
                                  const mysql_harness::Path &config_file_path);
@@ -537,6 +540,8 @@ class ConfigGenerator {
 #endif
 
   mysqlrouter::MetadataSchemaVersion schema_version_;
+
+  std::string plugin_folder_;
 };
 }  // namespace mysqlrouter
 #endif  // ROUTER_CONFIG_GENERATOR_INCLUDED
