@@ -4,6 +4,8 @@
 
 . inc/common.sh
 
+[[ $EUID -eq 0 ]] && skip_test "Can not be run by root"
+
 start_server --innodb_file_per_table
 
 run_cmd $MYSQL $MYSQL_ARGS <<EOF
@@ -18,23 +20,23 @@ EOF
 # Test that wrong directory permissions result in a backup failure
 # for both InnoDB and non-InnoDB files
 chmod 000 $MYSQLD_DATADIR/test_bug664986_innodb
-run_cmd_expect_failure $IB_BIN $IB_ARGS --no-timestamp $topdir/backup
+run_cmd_expect_failure $XB_BIN $XB_ARGS --backup -target-dir=$topdir/backup
 chmod 777 $MYSQLD_DATADIR/test_bug664986_innodb
 rm -rf $topdir/backup
 
 chmod 000 $MYSQLD_DATADIR/test_bug664986_myisam
-run_cmd_expect_failure $IB_BIN $IB_ARGS --no-timestamp $topdir/backup
+run_cmd_expect_failure $XB_BIN $XB_ARGS --backup -target-dir=$topdir/backup
 chmod 777 $MYSQLD_DATADIR/test_bug664986_myisam
 rm -rf $topdir/backup
 
 # Test that wrong file permissions result in a backup failure
 # for both InnoDB and non-InnoDB files
 chmod 000 $MYSQLD_DATADIR/test_bug664986_innodb/t.ibd
-run_cmd_expect_failure $IB_BIN $IB_ARGS --no-timestamp $topdir/backup
+run_cmd_expect_failure $XB_BIN $XB_ARGS --backup -target-dir=$topdir/backup
 chmod 644 $MYSQLD_DATADIR/test_bug664986_innodb/t.ibd
 rm -rf $topdir/backup
 
 chmod 000 $MYSQLD_DATADIR/test_bug664986_myisam/t.MYD
-run_cmd_expect_failure $IB_BIN $IB_ARGS --no-timestamp $topdir/backup
+run_cmd_expect_failure $XB_BIN $XB_ARGS --backup -target-dir=$topdir/backup
 chmod 644 $MYSQLD_DATADIR/test_bug664986_myisam/t.MYD
 rm -rf $topdir/backup
