@@ -1,15 +1,16 @@
-/* Copyright (c) 2003, 2021, Oracle and/or its affiliates.
+/* Copyright (c) 2003, 2024, Oracle and/or its affiliates.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2.0,
    as published by the Free Software Foundation.
 
-   This program is also distributed with certain software (including
+   This program is designed to work with certain software (including
    but not limited to OpenSSL) that is licensed under separate terms,
    as designated in a particular file or component or in included license
    documentation.  The authors of MySQL hereby grant you an additional
    permission to link the program and your derivative works with the
-   separately licensed software that they have included with MySQL.
+   separately licensed software that they have either included with
+   the program or referenced in the documentation.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -21,24 +22,20 @@
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
 */
 
-
-
 #include <signaldata/FsConf.hpp>
 
-bool 
-printFSCONF(FILE * output, const Uint32 * theData, Uint32 len, Uint16 receiverBlockNo){
-  
-  const FsConf * const sig = (FsConf *) theData;
-  
+bool printFSCONF(FILE *output, const Uint32 *theData, Uint32 len,
+                 Uint16 /*receiverBlockNo*/) {
+  const FsConf *const sig = (const FsConf *)theData;
+
   fprintf(output, " UserPointer: %d\n", sig->userPointer);
 
-  if (len > 1){
+  if (len > 1) {
     // Only valid if this is a FSOPENCONF
     fprintf(output, " FilePointer/Bytes_read: %d\n", sig->filePointer);
   }
 
-  if (len > 2)
-  {
+  if (len > 2) {
     fprintf(output, " FileInfo: %08x\n", sig->fileInfo);
   }
 
