@@ -1,17 +1,18 @@
 /*
-   Copyright (c) 2008, 2023, Oracle and/or its affiliates.
+   Copyright (c) 2008, 2024, Oracle and/or its affiliates.
     Use is subject to license terms.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2.0,
    as published by the Free Software Foundation.
 
-   This program is also distributed with certain software (including
+   This program is designed to work with certain software (including
    but not limited to OpenSSL) that is licensed under separate terms,
    as designated in a particular file or component or in included license
    documentation.  The authors of MySQL hereby grant you an additional
    permission to link the program and your derivative works with the
-   separately licensed software that they have included with MySQL.
+   separately licensed software that they have either included with
+   the program or referenced in the documentation.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -231,9 +232,7 @@ TESTCASE("AtrtClient", "Test AtrtClient class") {
 /*
   $> testNDBT -n SqlClient
 */
-TESTCASE("SqlClient", "Test SqlClient class") {
-  INITIALIZER(runTestSqlClient);
-}
+TESTCASE("SqlClient", "Test SqlClient class") { INITIALIZER(runTestSqlClient); }
 TESTCASE("SqlClientThreads", "Test SqlClient class with threads") {
   STEPS(runTestSqlClientThread, 10);
 }
